@@ -1,5 +1,6 @@
-﻿#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
+
+
+
 
 
 from .tools import TYPE_NULL, TYPE_BOOL, TYPE_INT, TYPE_FLOAT, TYPE_STR, TYPE_ARRAY, TYPE_OBJECT, \
@@ -12,4 +13,4 @@ from .tools import TYPE_NULL, TYPE_BOOL, TYPE_INT, TYPE_FLOAT, TYPE_STR, TYPE_AR
 
 
 
-__version__ = "0.2022.2.16"
\ No newline at end of file
+__version__ = "0.2022.3.2"
\ No newline at end of file
